@@ -1,51 +1,30 @@
 
 package CPAN::DistnameInfo;
 
-$VERSION = "0.12_01";
-$VERSION =~ tr/_//d;
+$VERSION = "0.02";
 use strict;
 
 sub distname_info {
   my $file = shift or return;
 
-  return ($file, undef, undef) if $file =~ /\P{ASCII}/;
-
   my ($dist, $version) = $file =~ /^
     ((?:[-+.]*(?:[A-Za-z0-9]+|(?<=\D)_|_(?=\D))*
-      (?:
-        [A-Za-z](?=[^A-Za-z]|$)
-        |
-        \d(?=-)
-      )(?<![._-][vV])
+     (?:
+	[A-Za-z](?=[^A-Za-z]|$)
+	|
+	\d(?=-)
+     )(?<![._-][vV])
     )+)(.*)
   $/xs or return ($file,undef,undef);
 
-  if ($dist =~ /-undef\z/ and ! length $version) {
-    $dist =~ s/-undef\z//;
-  }
-
-  # Remove potential -withoutworldwriteables suffix
-  $version =~ s/-withoutworldwriteables$//;
-
   if ($version =~ /^(-[Vv].*)-(\d.*)/) {
+   
     # Catch names like Unicode-Collate-Standard-V3_1_1-0.1
     # where the V3_1_1 is part of the distname
     $dist .= $1;
     $version = $2;
   }
 
-  if ($version =~ /(.+_.*)-(\d.*)/) {
-      # Catch names like Task-Deprecations5_14-1.00.tar.gz where the 5_14 is
-      # part of the distname. However, names like libao-perl_0.03-1.tar.gz
-      # should still have 0.03-1 as their version.
-      $dist .= $1;
-      $version = $2;
-  }
-
-  # Normalize the Dist.pm-1.23 convention which CGI.pm and
-  # a few others use.
-  $dist =~ s{\.pm$}{};
-
   $version = $1
     if !length $version and $dist =~ s/-(\d+\w)$//;
 
@@ -64,7 +43,7 @@ sub distname_info {
     if ($file =~ /^perl-?\d+\.(\d+)(?:\D(\d+))?(-(?:TRIAL|RC)\d+)?$/) {
       $dev = 1 if (($1 > 6 and $1 & 1) or ($2 and $2 >= 50)) or $3;
     }
-    elsif ($version =~ /\d\D\d+_\d/ or $version =~ s/-TRIAL[0-9]*$//) {
+    elsif ($version =~ /\d\D\d+_\d/) {
       $dev = 1;
     }
   }
@@ -79,16 +58,15 @@ sub new {
   my $class = shift;
   my $distfile = shift;
 
+  my %info;
+
   $distfile =~ s,//+,/,g;
 
-  my %info = ( pathname => $distfile );
-
-  ($info{filename} = $distfile) =~ s,^(((.*?/)?authors/)?id/)?([A-Z])/(\4[A-Z])/(\5[-A-Z0-9]*)/,,
+  ($info{filename} = $distfile) =~ s,^(((.*?/)?authors/)?id/)?([A-Z])/(\4[A-Z])/(\5[-A-Z]+)/,,
     and $info{cpanid} = $6;
 
-  if ($distfile =~ m,([^/]+)\.(tar\.(?:g?z|bz2|xz)|zip|tgz)$,i) { # support more ?
+  if ($distfile =~ m,([^/]+)\.(?:tar\.g?z|zip|tgz)$,i) { # support more ?
     $info{distvname} = $1;
-    $info{extension} = $2;
   }
 
   @info{qw(dist version beta)} = distname_info($info{distvname});
@@ -103,8 +81,6 @@ sub maturity  { shift->{maturity} }
 sub filename  { shift->{filename} }
 sub cpanid    { shift->{cpanid} }
 sub distvname { shift->{distvname} }
-sub extension { shift->{extension} }
-sub pathname  { shift->{pathname} }
 
 sub properties { %{ $_[0] } }
 
@@ -128,8 +104,6 @@ CPAN::DistnameInfo - Extract distribution name and version from a distribution f
   my $filename  = $d->filename;  # "CPAN-DistnameInfo-0.02.tar.gz"
   my $cpanid    = $d->cpanid;    # "GBARR"
   my $distvname = $d->distvname; # "CPAN-DistnameInfo-0.02"
-  my $extension = $d->extension; # "tar.gz"
-  my $pathname  = $d->pathname;  # "authors/id/G/GB/GBARR/..."
 
   my %prop = $d->properties;
 
@@ -174,14 +148,6 @@ that was passed in.
 
 The maturity of the distribution. This will be either C<released> or C<developer>
 
-=item extension
-
-The extension of the distribution, often used to denote the archive type (e.g. 'tar.gz')
-
-=item pathname
-
-The pathname that was passed to the constructor when creating the object.
-
 =item properties
 
 This will return a list of key-value pairs, suitable for assigning to a hash,
